
// Connector 90 degree for 12mm round rods or 10mm square rods
// Mostly parametric but optimized for implemented size
//
// Version 017 : Michael Abel 2017
// Version 018 : Michael Abel 2021 increase support width
// Version 019 : Michael Abel 2021 increase screw head size
// Version 020 : Michael Abel 2021 increase screw distance from center, fine tune support, intend
//
// Licensed under Creative Commons Attribution-ShareAlike: CC BY-SA 
// https://creativecommons.org/licenses/by-sa/4.0/
//
// To assemble, take a saw and clean up the slot as well as the bridge.
// Mount with 20mm M5 hex screws and M5 nuts.

//Overall dimensions
length=50;
width=20;

extra=0.3; //extra space for printing tolerance; It even apperars that some rods are up to 0.2 mm larger

rod_rectangular=10 +2*extra;
rod_round=12 +2*extra;

rod_distance=2.5; // from the center
rod_distance_rect=3.5; // from the center

screw_distance=19; // from the center

screwD=5 + extra; // Screw Diameter
screwHeadD=9.0; //Real screw head 8.3
screwHeadH=5;

phaseBoxH=6;
phaseBoxSmall=1;

diffOffset=1; // just to be sure when doing a difference

slot=2; // Width of the horizontal slot



additionalSupportHeight=0.4; //Thickness of the bridge (one on my toolchain)
additionalSupportWidth=0.5; //Thickness of the walls (one on my toolchain)

//little supports for horizontal slot
slotSupportOffset_a= additionalSupportWidth; //width of the slot support; set to -0.01 for solid
//little supports for vertical slot
slotSupportOffset_b= -0.01; //width of the slot support; set to -0.01 for solid

slotSupportSpacing=1.8;
magic=0; //magic shift value to adjust the exact position of the supports in the horizontal slot

slotSupportSpacingHole=3.15;
slotSupportAmount=20;

m5_nut_diameter = 8+2*extra; //flat side to flat side
m5_nut_thickness = 4;

nut_edge=360/12;


module nut(d,h,horizontal=true){
cornerdiameter =  (d / 2) / cos (180 / 6);
cylinder(h = h, r = cornerdiameter, $fn = 6);
}

//Cube with slots so that we can use it as support and saw it away
// Parameters [pieces, length, width, thickness, offset]
module cutCube(x){
  for (i =[0:x[0]]) //iterate over length
  {
    translate([i*(x[4]+x[1]),0,0])
      cube( [x[1], x[2], x[3]]);
  }
}

// Enable to see the cutCube
// translate([0,0,30])
// cutCube( [10, 2 ,20, 0.5, 0.4]);

// The main thing
union(){
    difference(){

        // base cube
        cube( [length,width,width]);

        // rectangular rods
        translate([length/2-rod_distance_rect, - diffOffset, width/2-rod_rectangular/2])
        rotate([0,0,90])
        cube( [width+2*diffOffset ,rod_rectangular,rod_rectangular]);

        translate([length/2 + rod_distance_rect, width/2 -rod_rectangular/2, -diffOffset ])
        rotate([0,-90,-90])
        cube( [width+2*diffOffset ,rod_rectangular,rod_rectangular]);

        //screws
        translate([ length/2 + screw_distance , -diffOffset , width/2])
        rotate([-90,0,0])
        cylinder( width + 2* diffOffset ,screwD/2,screwD/2, $fn = 50);

        translate([ length/2 - screw_distance , width/2 , -diffOffset])
        rotate([0,0,0])
        cylinder( width + 2* diffOffset ,screwD/2 ,screwD/2, $fn = 50);

        //screw heads
        translate([length/2 - screw_distance, width/2, width -screwHeadH])
        rotate([0, 0, 0])
        cylinder( screwHeadH +diffOffset ,screwHeadD/2 ,screwHeadD/2, $fn = 50);

        translate([length/2 + screw_distance, width - screwHeadH, width/2])
        rotate([-90, 0, 0])
        cylinder( screwHeadH +diffOffset ,screwHeadD/2 ,screwHeadD/2, $fn = 50);

        //nuts
        translate([length/2 - screw_distance,  width/2,-diffOffset])
        rotate([0,0, nut_edge])
        nut(m5_nut_diameter, m5_nut_thickness+diffOffset, false);

        translate([length/2 + screw_distance, -diffOffset, width/2])
        rotate([ -90, 0, 0])
        rotate([0,0, nut_edge])
        nut(m5_nut_diameter,4+diffOffset,false);

        //round rods
        translate([length/2 - rod_round/2 - rod_distance , -diffOffset,width/2])
        rotate([0,-90,-90])
        cylinder( width+2*diffOffset ,rod_round/2,rod_round/2, $fn = 50);

        translate([length/2+rod_distance + rod_round/2,  width/2, -diffOffset])
        rotate([0,0,90])
        cylinder( width+2*diffOffset ,rod_round/2,rod_round/2, $fn = 50);

        //horizontal slot
        translate([ length/2 - rod_distance_rect - rod_rectangular/2 -magic, - diffOffset, width/2 + slot/2])
        rotate([0,180,0])
        cutCube( [slotSupportAmount, slotSupportSpacing, width + 2*diffOffset, slot , slotSupportOffset_a]);

        //vertical slot
        translate([ length/2 + rod_distance_rect + rod_rectangular/2, width/2 + slot/2 , -diffOffset])
        rotate([90,0,0])
        cutCube( [slotSupportAmount, slotSupportSpacing, width + 2*diffOffset, slot , slotSupportOffset_b]);

        // large bevel on the sides beside the screws
        rotate([90,0,0])
        translate([ -phaseBoxH /sqrt(2) , -diffOffset, 0]) //move it to zero
        rotate([0, 45, 0])
        cube( [ phaseBoxH ,width +2*diffOffset, phaseBoxH]);

        translate([ 0, width, 0])
        rotate([90,0,0])
        translate([ -phaseBoxH /sqrt(2) , -diffOffset, 0]) //move it to zero
        rotate([0, 45, 0])
        cube( [ phaseBoxH ,width +2*diffOffset, phaseBoxH]);

        translate([ length, 0, 0])
        translate([ -phaseBoxH /sqrt(2) , -diffOffset, 0]) //move it to zero
        rotate([0, 45, 0])
        cube( [ phaseBoxH ,width +2*diffOffset, phaseBoxH]);

        translate([ length, 0, width])
        translate([ -phaseBoxH /sqrt(2) , -diffOffset, 0]) //move it to zero
        rotate([0, 45, 0])
        cube( [ phaseBoxH ,width +2*diffOffset, phaseBoxH]);

        //small bevel at the long edges
        translate([ diffOffset+length/2, 0, 0]) //move it exactly to the edge
        rotate([45, 0, 0])
        cube( [ length , phaseBoxSmall, phaseBoxSmall], center=true);

        translate([ diffOffset+length/2, width, 0])
        rotate([45, 0, 0])
        cube( [ length , phaseBoxSmall, phaseBoxSmall], center=true);

        translate([ diffOffset+length/2, 0, width])
        rotate([45, 0, 0])
        cube( [ length , phaseBoxSmall, phaseBoxSmall], center=true);

        translate([ diffOffset+length/2, width, width])
        rotate([45, 0, 0])
        cube( [ length , phaseBoxSmall, phaseBoxSmall], center=true);

        }

    //additional support

    //build a bridge
    translate([length/2-rod_distance_rect-rod_rectangular/2, width/2, width/2+rod_rectangular/4])
    rotate([0,0,90])
    cube( [width ,rod_rectangular*1.2,additionalSupportHeight], center=true);

    //add supports
    translate([12.3, 0, width/2+rod_rectangular/4])
    cutCube( [3-1, slotSupportOffset_a, width, 4 , slotSupportSpacingHole]);

}


